<?php

return [
    'Names' => [
        'aa' => '阿法尔语',
        'ab' => '阿布哈西亚语',
        'ace' => '亚齐语',
        'ach' => '阿乔利语',
        'ada' => '阿当梅语',
        'ady' => '阿迪格语',
        'ae' => '阿维斯塔语',
        'af' => '南非荷兰语',
        'afh' => '阿弗里希利语',
        'agq' => '亚罕语',
        'ain' => '阿伊努语',
        'ak' => '阿肯语',
        'akk' => '阿卡德语',
        'ale' => '阿留申语',
        'alt' => '南阿尔泰语',
        'am' => '阿姆哈拉语',
        'an' => '阿拉贡语',
        'ang' => '古英语',
        'ann' => '奥博洛语',
        'anp' => '昂加语',
        'ar' => '阿拉伯语',
        'arc' => '阿拉米语',
        'arn' => '马普切语',
        'arp' => '阿拉帕霍语',
        'ars' => '纳吉迪阿拉伯语',
        'arw' => '阿拉瓦克语',
        'as' => '阿萨姆语',
        'asa' => '帕雷语',
        'ast' => '阿斯图里亚斯语',
        'atj' => '阿提卡米克语',
        'av' => '阿瓦尔语',
        'awa' => '阿瓦德语',
        'ay' => '艾马拉语',
        'az' => '阿塞拜疆语',
        'ba' => '巴什基尔语',
        'bal' => '俾路支语',
        'ban' => '巴厘语',
        'bas' => '巴萨语',
        'bax' => '巴姆穆语',
        'bbj' => '戈马拉语',
        'be' => '白俄罗斯语',
        'bej' => '贝沙语',
        'bem' => '本巴语',
        'bez' => '贝纳语',
        'bfd' => '巴非特语',
        'bg' => '保加利亚语',
        'bgc' => '哈里亚纳语',
        'bgn' => '西俾路支语',
        'bho' => '博杰普尔语',
        'bi' => '比斯拉马语',
        'bik' => '比科尔语',
        'bin' => '比尼语',
        'bkm' => '科姆语',
        'bla' => '西克西卡语',
        'blo' => '阿尼语',
        'bm' => '班巴拉语',
        'bn' => '孟加拉语',
        'bo' => '藏语',
        'br' => '布列塔尼语',
        'bra' => '布拉杰语',
        'brx' => '博多语',
        'bs' => '波斯尼亚语',
        'bss' => '阿库色语',
        'bua' => '布里亚特语',
        'bug' => '布吉语',
        'bum' => '布鲁语',
        'byn' => '比林语',
        'byv' => '梅敦巴语',
        'ca' => '加泰罗尼亚语',
        'cad' => '卡多语',
        'car' => '加勒比语',
        'cay' => '卡尤加语',
        'cch' => '阿灿语',
        'ccp' => '查克玛语',
        'ce' => '车臣语',
        'ceb' => '宿务语',
        'cgg' => '奇加语',
        'ch' => '查莫罗语',
        'chb' => '奇布查语',
        'chg' => '察合台语',
        'chk' => '楚克语',
        'chm' => '马里语',
        'chn' => '奇努克混合语',
        'cho' => '乔克托语',
        'chp' => '奇佩维安语',
        'chr' => '切罗基语',
        'chy' => '夏延语',
        'ckb' => '中库尔德语',
        'clc' => '奇尔科廷语',
        'co' => '科西嘉语',
        'cop' => '科普特语',
        'cr' => '克里语',
        'crg' => '米其芙语',
        'crh' => '克里米亚鞑靼语',
        'crj' => '东南部克里语',
        'crk' => '平原克里语',
        'crl' => '东北部克里语',
        'crm' => '穆斯克里语',
        'crr' => '卡罗莱纳州阿尔冈昆语',
        'crs' => '塞舌尔克里奥尔语',
        'cs' => '捷克语',
        'csb' => '卡舒比语',
        'csw' => '沼泽克里语',
        'cu' => '教会斯拉夫语',
        'cv' => '楚瓦什语',
        'cy' => '威尔士语',
        'da' => '丹麦语',
        'dak' => '达科他语',
        'dar' => '达尔格瓦语',
        'dav' => '台塔语',
        'de' => '德语',
        'del' => '特拉华语',
        'den' => '史拉维语',
        'dgr' => '多格里布语',
        'din' => '丁卡语',
        'dje' => '哲尔马语',
        'doi' => '多格拉语',
        'dsb' => '下索布语',
        'dua' => '杜阿拉语',
        'dum' => '中古荷兰语',
        'dv' => '迪维希语',
        'dyo' => '朱拉语',
        'dyu' => '迪尤拉语',
        'dz' => '宗卡语',
        'dzg' => '达扎葛语',
        'ebu' => '恩布语',
        'ee' => '埃维语',
        'efi' => '埃菲克语',
        'egy' => '古埃及语',
        'eka' => '艾卡朱克语',
        'el' => '希腊语',
        'elx' => '埃兰语',
        'en' => '英语',
        'enm' => '中古英语',
        'eo' => '世界语',
        'es' => '西班牙语',
        'et' => '爱沙尼亚语',
        'eu' => '巴斯克语',
        'ewo' => '埃翁多语',
        'fa' => '波斯语',
        'fan' => '芳格语',
        'fat' => '芳蒂语',
        'ff' => '富拉语',
        'fi' => '芬兰语',
        'fil' => '菲律宾语',
        'fj' => '斐济语',
        'fo' => '法罗语',
        'fon' => '丰语',
        'fr' => '法语',
        'frc' => '卡真法语',
        'frm' => '中古法语',
        'fro' => '古法语',
        'frr' => '北弗里西亚语',
        'frs' => '东弗里西亚语',
        'fur' => '弗留利语',
        'fy' => '西弗里西亚语',
        'ga' => '爱尔兰语',
        'gaa' => '加族语',
        'gag' => '加告兹语',
        'gan' => '赣语',
        'gay' => '迦约语',
        'gba' => '格巴亚语',
        'gd' => '苏格兰盖尔语',
        'gez' => '吉兹语',
        'gil' => '吉尔伯特语',
        'gl' => '加利西亚语',
        'gmh' => '中古高地德语',
        'gn' => '瓜拉尼语',
        'goh' => '古高地德语',
        'gon' => '冈德语',
        'gor' => '哥伦打洛语',
        'got' => '哥特语',
        'grb' => '格列博语',
        'grc' => '古希腊语',
        'gsw' => '瑞士德语',
        'gu' => '古吉拉特语',
        'guz' => '古西语',
        'gv' => '马恩语',
        'gwi' => '哥威迅语',
        'ha' => '豪萨语',
        'hai' => '海达语',
        'hak' => '客家语',
        'haw' => '夏威夷语',
        'hax' => '南海达语',
        'he' => '希伯来语',
        'hi' => '印地语',
        'hil' => '希利盖农语',
        'hit' => '赫梯语',
        'hmn' => '苗语',
        'ho' => '希里莫图语',
        'hr' => '克罗地亚语',
        'hsb' => '上索布语',
        'hsn' => '湘语',
        'ht' => '海地克里奥尔语',
        'hu' => '匈牙利语',
        'hup' => '胡帕语',
        'hur' => '哈尔魁梅林语',
        'hy' => '亚美尼亚语',
        'hz' => '赫雷罗语',
        'ia' => '国际语',
        'iba' => '伊班语',
        'ibb' => '伊比比奥语',
        'id' => '印度尼西亚语',
        'ie' => '国际文字（E）',
        'ig' => '伊博语',
        'ii' => '凉山彝语',
        'ik' => '伊努皮克语',
        'ikt' => '西加拿大因纽特语',
        'ilo' => '伊洛卡诺语',
        'inh' => '印古什语',
        'io' => '伊多语',
        'is' => '冰岛语',
        'it' => '意大利语',
        'iu' => '因纽特语',
        'ja' => '日语',
        'jbo' => '逻辑语',
        'jgo' => '恩艮巴语',
        'jmc' => '马切姆语',
        'jpr' => '犹太波斯语',
        'jrb' => '犹太阿拉伯语',
        'jv' => '爪哇语',
        'ka' => '格鲁吉亚语',
        'kaa' => '卡拉卡尔帕克语',
        'kab' => '卡拜尔语',
        'kac' => '克钦语',
        'kaj' => '卡捷语',
        'kam' => '卡姆巴语',
        'kaw' => '卡威语',
        'kbd' => '卡巴尔德语',
        'kbl' => '加涅姆布语',
        'kcg' => '卡塔布语',
        'kde' => '马孔德语',
        'kea' => '卡布佛得鲁语',
        'kfo' => '克罗语',
        'kg' => '刚果语',
        'kgp' => '坎刚语',
        'kha' => '卡西语',
        'kho' => '和田语',
        'khq' => '西桑海语',
        'ki' => '吉库尤语',
        'kj' => '宽亚玛语',
        'kk' => '哈萨克语',
        'kkj' => '卡库语',
        'kl' => '格陵兰语',
        'kln' => '卡伦金语',
        'km' => '高棉语',
        'kmb' => '金邦杜语',
        'kn' => '卡纳达语',
        'ko' => '韩语',
        'koi' => '科米-彼尔米亚克语',
        'kok' => '孔卡尼语',
        'kos' => '科斯拉伊语',
        'kpe' => '克佩列语',
        'kr' => '卡努里语',
        'krc' => '卡拉恰伊巴尔卡尔语',
        'krl' => '卡累利阿语',
        'kru' => '库鲁克语',
        'ks' => '克什米尔语',
        'ksb' => '香巴拉语',
        'ksf' => '巴菲亚语',
        'ksh' => '科隆语',
        'ku' => '库尔德语',
        'kum' => '库梅克语',
        'kut' => '库特奈语',
        'kv' => '科米语',
        'kw' => '康沃尔语',
        'kwk' => '夸夸瓦拉语',
        'kxv' => '库维语',
        'ky' => '吉尔吉斯语',
        'la' => '拉丁语',
        'lad' => '拉迪诺语',
        'lag' => '朗吉语',
        'lah' => '西旁遮普语',
        'lam' => '兰巴语',
        'lb' => '卢森堡语',
        'lez' => '列兹金语',
        'lg' => '卢干达语',
        'li' => '林堡语',
        'lij' => '利古里亚语',
        'lil' => '利洛埃特语',
        'lkt' => '拉科塔语',
        'lmo' => '伦巴第语',
        'ln' => '林加拉语',
        'lo' => '老挝语',
        'lol' => '蒙戈语',
        'lou' => '路易斯安那克里奥尔语',
        'loz' => '洛齐语',
        'lrc' => '北卢尔语',
        'lsm' => '萨米亚语',
        'lt' => '立陶宛语',
        'lu' => '鲁巴加丹加语',
        'lua' => '卢巴-卢拉语',
        'lui' => '卢伊塞诺语',
        'lun' => '隆达语',
        'luo' => '卢奥语',
        'lus' => '米佐语',
        'luy' => '卢雅语',
        'lv' => '拉脱维亚语',
        'mad' => '马都拉语',
        'maf' => '马法语',
        'mag' => '摩揭陀语',
        'mai' => '迈蒂利语',
        'mak' => '望加锡语',
        'man' => '曼丁哥语',
        'mas' => '马赛语',
        'mde' => '马坝语',
        'mdf' => '莫克沙语',
        'mdr' => '曼达尔语',
        'men' => '门德语',
        'mer' => '梅鲁语',
        'mfe' => '毛里求斯克里奥尔语',
        'mg' => '马拉加斯语',
        'mga' => '中古爱尔兰语',
        'mgh' => '马库阿-梅托语',
        'mgo' => '梅塔语',
        'mh' => '马绍尔语',
        'mi' => '毛利语',
        'mic' => '密克马克语',
        'min' => '米南佳保语',
        'mk' => '马其顿语',
        'ml' => '马拉雅拉姆语',
        'mn' => '蒙古语',
        'mnc' => '满语',
        'mni' => '曼尼普尔语',
        'moe' => '因努埃蒙语',
        'moh' => '摩霍克语',
        'mos' => '莫西语',
        'mr' => '马拉地语',
        'ms' => '马来语',
        'mt' => '马耳他语',
        'mua' => '蒙当语',
        'mus' => '克里克语',
        'mwl' => '米兰德斯语',
        'mwr' => '马尔瓦里语',
        'my' => '缅甸语',
        'mye' => '姆耶内语',
        'myv' => '厄尔兹亚语',
        'mzn' => '马赞德兰语',
        'na' => '瑙鲁语',
        'nan' => '闽南语',
        'nap' => '那不勒斯语',
        'naq' => '纳马语',
        'nb' => '书面挪威语',
        'nd' => '北恩德贝勒语',
        'nds' => '低地德语',
        'ne' => '尼泊尔语',
        'new' => '尼瓦尔语',
        'ng' => '恩东加语',
        'nia' => '尼亚斯语',
        'niu' => '纽埃语',
        'nl' => '荷兰语',
        'nmg' => '夸西奥语',
        'nn' => '挪威尼诺斯克语',
        'nnh' => '恩甘澎语',
        'no' => '挪威语',
        'nog' => '诺盖语',
        'non' => '古诺尔斯语',
        'nqo' => '西非书面文字',
        'nr' => '南恩德贝勒语',
        'nso' => '北索托语',
        'nus' => '努埃尔语',
        'nv' => '纳瓦霍语',
        'nwc' => '古典尼瓦尔语',
        'ny' => '齐切瓦语',
        'nym' => '尼扬韦齐语',
        'nyn' => '尼昂科勒语',
        'nyo' => '尼奥罗语',
        'nzi' => '恩济马语',
        'oc' => '奥克语',
        'oj' => '奥吉布瓦语',
        'ojb' => '西北部奥吉布瓦语',
        'ojc' => '中奥吉布瓦语',
        'ojs' => '欧吉克里语',
        'ojw' => '西奥吉布瓦语',
        'oka' => '欧肯那根语',
        'om' => '奥罗莫语',
        'or' => '奥里亚语',
        'os' => '奥塞梯语',
        'osa' => '欧塞奇语',
        'ota' => '奥斯曼土耳其语',
        'pa' => '旁遮普语',
        'pag' => '邦阿西南语',
        'pal' => '巴拉维语',
        'pam' => '邦板牙语',
        'pap' => '帕皮阿门托语',
        'pau' => '帕劳语',
        'pcm' => '尼日利亚皮钦语',
        'peo' => '古波斯语',
        'phn' => '腓尼基语',
        'pi' => '巴利语',
        'pis' => '皮京语',
        'pl' => '波兰语',
        'pon' => '波纳佩语',
        'pqm' => '马利塞-帕萨马科迪语',
        'prg' => '普鲁士语',
        'pro' => '古普罗文斯语',
        'ps' => '普什图语',
        'pt' => '葡萄牙语',
        'qu' => '克丘亚语',
        'quc' => '基切语',
        'raj' => '拉贾斯坦语',
        'rap' => '拉帕努伊语',
        'rar' => '拉罗汤加语',
        'rhg' => '罗兴亚语',
        'rif' => '里夫语',
        'rm' => '罗曼什语',
        'rn' => '隆迪语',
        'ro' => '罗马尼亚语',
        'rof' => '兰博语',
        'rom' => '吉普赛语',
        'ru' => '俄语',
        'rup' => '阿罗马尼亚语',
        'rw' => '卢旺达语',
        'rwk' => '罗瓦语',
        'sa' => '梵语',
        'sad' => '桑达韦语',
        'sah' => '萨哈语',
        'sam' => '萨马利亚阿拉姆语',
        'saq' => '桑布鲁语',
        'sas' => '萨萨克语',
        'sat' => '桑塔利语',
        'sba' => '甘拜语',
        'sbp' => '桑古语',
        'sc' => '萨丁语',
        'scn' => '西西里语',
        'sco' => '苏格兰语',
        'sd' => '信德语',
        'sdh' => '南库尔德语',
        'se' => '北方萨米语',
        'see' => '塞内卡语',
        'seh' => '塞纳语',
        'sel' => '塞尔库普语',
        'ses' => '东桑海语',
        'sg' => '桑戈语',
        'sga' => '古爱尔兰语',
        'sh' => '塞尔维亚-克罗地亚语',
        'shi' => '希尔哈语',
        'shn' => '掸语',
        'shu' => '乍得阿拉伯语',
        'si' => '僧伽罗语',
        'sid' => '悉达摩语',
        'sk' => '斯洛伐克语',
        'skr' => '色莱基语',
        'sl' => '斯洛文尼亚语',
        'slh' => '南卢舒特种子语',
        'sm' => '萨摩亚语',
        'sma' => '南萨米语',
        'smj' => '吕勒萨米语',
        'smn' => '伊纳里萨米语',
        'sms' => '斯科特萨米语',
        'sn' => '绍纳语',
        'snk' => '索宁克语',
        'so' => '索马里语',
        'sog' => '粟特语',
        'sq' => '阿尔巴尼亚语',
        'sr' => '塞尔维亚语',
        'srn' => '苏里南汤加语',
        'srr' => '塞雷尔语',
        'ss' => '斯瓦蒂语',
        'ssy' => '萨霍语',
        'st' => '南索托语',
        'str' => '海峡萨利希语',
        'su' => '巽他语',
        'suk' => '苏库马语',
        'sus' => '苏苏语',
        'sux' => '苏美尔语',
        'sv' => '瑞典语',
        'sw' => '斯瓦希里语',
        'swb' => '科摩罗语',
        'syc' => '古典叙利亚语',
        'syr' => '叙利亚语',
        'szl' => '西里西亚语',
        'ta' => '泰米尔语',
        'tce' => '南塔穹语',
        'te' => '泰卢固语',
        'tem' => '泰姆奈语',
        'teo' => '特索语',
        'ter' => '特伦诺语',
        'tet' => '德顿语',
        'tg' => '塔吉克语',
        'tgx' => '塔吉什语',
        'th' => '泰语',
        'tht' => '塔尔坦语',
        'ti' => '提格利尼亚语',
        'tig' => '提格雷语',
        'tiv' => '蒂夫语',
        'tk' => '土库曼语',
        'tkl' => '托克劳语',
        'tl' => '他加禄语',
        'tlh' => '克林贡语',
        'tli' => '特林吉特语',
        'tmh' => '塔马奇克语',
        'tn' => '茨瓦纳语',
        'to' => '汤加语',
        'tog' => '尼亚萨汤加语',
        'tok' => '道本语',
        'tpi' => '托克皮辛语',
        'tr' => '土耳其语',
        'trv' => '赛德克语',
        'trw' => '托尔瓦利语',
        'ts' => '聪加语',
        'tsi' => '钦西安语',
        'tt' => '鞑靼语',
        'ttm' => '北塔穹语',
        'tum' => '通布卡语',
        'tvl' => '图瓦卢语',
        'tw' => '契维语',
        'twq' => '北桑海语',
        'ty' => '塔希提语',
        'tyv' => '图瓦语',
        'tzm' => '塔马齐格特语',
        'udm' => '乌德穆尔特语',
        'ug' => '维吾尔语',
        'uga' => '乌加里特语',
        'uk' => '乌克兰语',
        'umb' => '翁本杜语',
        'ur' => '乌尔都语',
        'uz' => '乌兹别克语',
        'vai' => '瓦伊语',
        've' => '文达语',
        'vec' => '威尼斯语',
        'vep' => '维普森语',
        'vi' => '越南语',
        'vmw' => '马库阿语',
        'vo' => '沃拉普克语',
        'vot' => '沃提克语',
        'vun' => '温旧语',
        'wa' => '瓦隆语',
        'wae' => '瓦尔瑟语',
        'wal' => '瓦拉莫语',
        'war' => '瓦瑞语',
        'was' => '瓦绍语',
        'wbp' => '瓦尔皮瑞语',
        'wo' => '沃洛夫语',
        'wuu' => '吴语',
        'xal' => '卡尔梅克语',
        'xh' => '科萨语',
        'xnr' => '康格里语',
        'xog' => '索加语',
        'yao' => '尧语',
        'yap' => '雅浦语',
        'yav' => '洋卞语',
        'ybb' => '耶姆巴语',
        'yi' => '意第绪语',
        'yo' => '约鲁巴语',
        'yrl' => '恩加图语',
        'yue' => '粤语',
        'za' => '壮语',
        'zap' => '萨波蒂克语',
        'zbl' => '布里斯符号',
        'zen' => '泽纳加语',
        'zgh' => '标准摩洛哥塔马塞特语',
        'zh' => '中文',
        'zu' => '祖鲁语',
        'zun' => '祖尼语',
        'zza' => '扎扎语',
    ],
    'LocalizedNames' => [
        'ar_001' => '现代标准阿拉伯语',
        'az_Arab' => '南阿塞拜疆语',
        'de_AT' => '奥地利德语',
        'de_CH' => '瑞士高地德语',
        'en_AU' => '澳大利亚英语',
        'en_CA' => '加拿大英语',
        'en_GB' => '英国英语',
        'en_US' => '美国英语',
        'es_419' => '拉丁美洲西班牙语',
        'es_ES' => '欧洲西班牙语',
        'es_MX' => '墨西哥西班牙语',
        'fa_AF' => '达里语',
        'fr_CA' => '加拿大法语',
        'fr_CH' => '瑞士法语',
        'hi_Latn' => '印地语（拉丁字母）',
        'nds_NL' => '低萨克森语',
        'nl_BE' => '弗拉芒语',
        'pt_BR' => '巴西葡萄牙语',
        'pt_PT' => '欧洲葡萄牙语',
        'ro_MD' => '摩尔多瓦语',
        'sw_CD' => '刚果斯瓦希里语',
        'zh_Hans' => '简体中文',
        'zh_Hant' => '繁体中文',
    ],
];
